@@ -6,7 +6,7 @@ use utf8;
 use strict;
 use warnings;
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use Moo;
 use SQL::Translator;
@@ -132,7 +132,7 @@ sub upgrade
 
     print "Upgrading database from version $from to $to\n";
 
-    if ($from == 0)
+    if ($from < 1)
     {
         $self->schema->storage->dbh->do("CREATE TABLE config ( " .
                                         "   name text NOT NULL, " .
@@ -141,6 +141,14 @@ sub upgrade
                                         ")");
         App::Zapzi::Config::set('schema_version', 1);
     }
+
+    if ($from < 2)
+    {
+        $self->schema->storage->dbh->do("ALTER TABLE articles " .
+                                        "ADD COLUMN " .
+                                        "   source NOT NULL DEFAULT '' ");
+        App::Zapzi::Config::set('schema_version', 2);
+    }
 }
 
 1;
@@ -155,7 +163,7 @@ App::Zapzi::Database - database access for Zapzi
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 DESCRIPTION
 
